@@ -74,3 +74,23 @@ test_that("get_nhdplushr runs", {
 
   expect(length(names(out)), 7)
 })
+
+test_that("downloaders run", {
+  skip_on_cran()
+  dir <- tempdir()
+  mess <- capture_messages(out <- download_nhdplusv2(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/NHDPlus_test.gdb.7z"))
+  unlink(dir, recursive = T)
+  expect_true(grepl("NHDPlus_test.gdb", out))
+
+  dir <- tempdir()
+  mess <- capture_messages(out <- download_rf1(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/rf1_test.e00.gz"))
+  unlink(dir, recursive = T)
+  expect_true(grepl("rf1_test.e00", out))
+
+  dir <- tempdir()
+  mess <- capture_messages(out <- download_wbd(outdir = dir, url = "https://usgs-r.github.io/nhdplusTools/data/WBD_test.gdb.zip"))
+  unlink(dir, recursive = T)
+  expect_true(grepl("WBD_test.gdb", out))
+})
+
+
